@@ -1,4 +1,4 @@
 from .portfolios import Portfolios
 from .product_metadata import ProductMetadata
 from .profiles import Profiles
-from .reports import Reports
+from .reports import Reports, Reporting
